<?php

class appPointPackDownloader {

    const POINTPACK_URL = 'https://www.pointpack.pl/rest/api/v1/';

    protected static $instance = array();
    protected $namespace = null;

    public static function getInstance($namespace) {
        if (!isset(self::$instance[$namespace])) {
            $className = __CLASS__;
            self::$instance[$namespace] = new $className();
            self::$instance[$namespace]->initialize($namespace);
        }

        return self::$instance[$namespace];
    }

    public function initialize($namespace) {
        $this->namespace = $namespace;
    }

    public function get($parameters = array(), $force = false) {
        if ($force === false && ($cache = $this->getCache()) !== false)
            return $cache;

        $response = $this->download($parameters);
        $this->saveCache($response);
        return $response;
    }

    public function download($parameters = array()) {
        $url = self::POINTPACK_URL.$this->namespace.(!empty($parameters) ? '?'.http_build_query($parameters, '', '&') : '');

        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
        $response = curl_exec($ch);
        curl_close($ch);

        return $response;
    }

    public function saveCache($content) {
        file_put_contents($this->getCacheFileName(), $content);
    }

    public function getCache($time = 1800) {
        if (file_exists($this->getCacheFileName()))
            if (filemtime($this->getCacheFileName()) + $time > time())
                return file_get_contents($this->getCacheFileName());
            else
                unlink($this->getCacheFileName());
        return false;
    }

    public function getCacheFileName() {
        $cacheDir = sfConfig::get('sf_root_dir').'/cache/frontend/'.SF_ENVIRONMENT.'/appPointPackPlugin';
        if (!file_exists($cacheDir))
            mkdir($cacheDir);

        return $cacheDir.'/'.$this->namespace.'.json';
    }
}

class appPointPackPoints {

    public static function getListOfPoints() {
        $content = json_decode(appPointPackDownloader::getInstance('points')->get(), true);
        return $content['entries'];
    }

    public static function getListOfCodPoints() {
        $content = json_decode(appPointPackDownloader::getInstance('points')->get(), true);
        $list = array();
        foreach ($content['entries'] as $point)
            if ($point['maxCashOnDelivery'] > 0)
                $list[] = $point;

        return $list;
    }

    public static function getPoint($number) {
        $content = json_decode(appPointPackDownloader::getInstance('points')->get(), true);
        foreach ($content['entries'] as $point)
            if ((int)$number == (int)$point['number']) {
                $point['fullAddress'] = $point['address']['street'] . ' ' .
                                        $point['address']['houseNumber'] . 
                                        (!empty($point['address']['apartmentNumber']) ? '/' . $point['address']['apartmentNumber'] : '');
                return $point;
            }

        return null;
    }
}


class appPointPackCouriers {

    public static function getListOfNames() {
        $data = json_decode(appPointPackDownloader::getInstance('couriercompanies')->get());

        $list = array();
        foreach ($data->entries as $company) {
            $list[$company->name] = $company->fullName;
            if ($company->cashOnDeliverySupport)
                $list[$company->name.'-COD'] = $company->fullName.' (płatność przy odbiorze)';
        }

        return $list;
    }

    public static function getAdditionalPrice($name) {
        $data = json_decode(appPointPackDownloader::getInstance('couriercompanies')->get());
        foreach ($data->entries as $company)
            if ($company->name == preg_replace('/\-COD/', '', $name))
                return (float)$company->pointPickupPrice;
        return (float)0;
    }

    public static function getReturnPrice($name) {
        $data = json_decode(appPointPackDownloader::getInstance('couriercompanies')->get());
        foreach ($data->entries as $company)
            if ($company->name == preg_replace('/\-COD/', '', $name))
                return (float)$company->pointReturnPrice;
        return (float)0;
    }
}
