<?php
class appPointPackBackendActions extends stActions {
    
    public function initializeParameters() {
        $this->config = stConfig::getInstance('appPointPackPlugin');

        $this->menuItems = $this->getMenuItems();

        $i18n = $this->getContext()->getI18n();
        $this->labels = array(
            'config{checkbox_terms}' => $i18n->__('Oświadczam, że zapoznałem się z regulaminem usług PointPack.pl S.A. i akceptuje wszystkie jego postanowienia.'),
            'config{checkbox_data_process}' => $i18n->__('Wyrażam zgodę na przetwarzanie przez PointPack.pl S.A. z siedzibą w Grodzisku Mazowieckim, 05-825, ul. Traugutta 42, danych osobowych w celach związanych z świadczeniem usługi.'),
            'config{checkbox_price}' => $i18n->__('Akceptuje cenę netto za usługę zwrotu przesyłek nieodebranych przez odbiorców z punktu PointPack.pl.'),
            'config{checkbox_invoice}' => $i18n->__('Wyrażam zgodę na otrzymywanie faktur za zrealizowane usługi PointPack.pl drogą elektroniczną na podany niżej adres e-mail.'),
            'config{checkbox_newsletter}' => $i18n->__('Wyrażam zgodę na otrzymywanie newslettera z informacjami o zmianach dot. PointPack.pl na podany niżej adres e-mail administratora lub właściciela sklepu internetowego.'),
            'config{checkbox_marketing}' => $i18n->__('Wyrażam zgodę na wykorzystanie logo sklepu internetowego i umieszczenie informacji o sklepie internetowym korzystającym z metody dostawy do punktów PointPack.pl w celach marketingowych przez PointPack.pl S.A. na portalu PointPack.pl.'),
            'config{invoice_email}' => $i18n->__('Adres e-mail dla faktur'),
            'config{newsletter_email}' => $i18n->__('Adres e-mail dla newslettera'),
            'config{marketing_description}' => $i18n->__('Opis sklepu'),
        );
    }

    protected function getMenuItems() {
        $i18n = $this->getContext()->getI18N();
        return array(
            'appPointPackBackend/index' => $i18n->__('Konfiguracja'),
            'appPointPackBackend/getPoints' => $i18n->__('Lista punktów dostawy'));
    }

    public function executeIndex() {
        $this->initializeParameters();

        $tmp = $this->config;

        if ($this->getRequest()->getMethod() == sfRequest::POST) {

            $send = false;
            foreach (array('active', 'invoice_email', 'newsletter_email', 'marketing_description') as $value)
                if ($tmp->get($value) != $this->getRequestParameter('config['.$value.']'))
                    $send = true;

            $this->config->setFromRequest('config');
            $this->config->save();

            if ($send)
                $this->sendMail();

            $this->setFlash('notice', $this->getContext()->getI18n()->__('Twoje zmiany zostały zapisane', null, 'stAdminGeneratorPlugin'));
        }
    }

    protected function sendMail() {
        $parameters = array('domain' => $this->getRequest()->getHost(),
                            'active' => $this->config->get('active'),
                            'invoice' => $this->config->get('invoice_email'),
                            'newsletter' => $this->config->get('newsletter_email'),
                            'description' => $this->config->get('marketing_description'),
                            );

        $plainMailMessage = stMailTemplate::render('appPointPackBackend/sendMailPlain', array('parameters' => $parameters));

        stMailer::getInstance()->setSubject('e-sklep')->setPlainMessage($plainMailMessage)->setTo('administrator@pointpack.pl')->send();
    }

    public function handleErrorIndex() {
        $this->initializeParameters();
        return sfView::SUCCESS;
    }

    public function executeGetPoints() {
        $this->menuItems = $this->getMenuItems();

        $downloader = appPointPackDownloader::getInstance('points');
        $points = json_decode($downloader->get(), true);

        $this->pointsCount = $this->pointsDate = '-';

        if (is_array($points)) {
            $this->pointsCount = $points['count'];
            $this->pointsDate = date('d.m.Y H:i', filemtime($downloader->getCacheFileName()));
        }

        if ($this->getRequest()->getMethod() == sfRequest::POST) {
            $downloader->get(array(), true);
            $this->setFlash('notice', $this->getContext()->getI18n()->__('Lista punktów została pobrana.'));
        }
    }

    public function executeGetPriceJson() {
        $this->setLayout(false);

        if ($this->getRequest()->hasParameter('name'))
            exit(json_encode(array('additional' => appPointPackCouriers::getAdditionalPrice($this->getRequestParameter('name')), 'return' => appPointPackCouriers::getReturnPrice($this->getRequestParameter('name')))));
        exit('-');
    }
}
